@@ -1,11 +1,12 @@
+# $Id: Function.pm,v 1.3 2002/10/23 18:54:38 comdog Exp $
 package Test::Data::Function;
-# $Id: Function.pm,v 1.2 2002/09/03 09:13:39 comdog Exp $
 use strict;
 
 use base qw(Exporter);
-use vars qw(@EXPORT);
+use vars qw(@EXPORT $VERSION);
 
-@EXPORT = qw(prototype_ok);
+@EXPORT  = qw(prototype_ok);
+$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ m/ (\d+) \. (\d+) /g;
 
 use Test::Builder;
 my $Test = Test::Builder->new();
@@ -16,19 +17,17 @@ Test::Data::Function -- test functions for functions
 
 =head1 SYNOPSIS
 
-use Test::Data::Function;
-
+	use Test::Data qw(Function);
 
 =head1 DESCRIPTION
 
+This module provides test functions for subroutine sorts of things.
 
-=head2 FUNCTIONS
-
+=head2 Functions
 
 =over 4
 
-=item prototype_ok( PROTOTYPE, SUB )
-
+=item prototype_ok( PROTOTYPE, SUB [, NAME ] )
 
 =cut
 
@@ -36,7 +35,7 @@ sub prototype_ok(\&$;$)
 	{
 	my $sub        = shift;
 	my $prototype  = shift;
-	my $name       = shift;
+	my $name       = shift || 'function prototype is correct';
 	
 	my $actual     = prototype( $sub );
 	my $test       = $actual eq $prototype;
@@ -59,9 +58,20 @@ sub prototype_ok(\&$;$)
 
 L<Test::Data>,
 L<Test::Data::Array>,
+L<Test::Data::Hash>, 
 L<Test::Data::Scalar>, 
 L<Test::Builder>
 
+=head1 SOURCE AVAILABILITY
+
+This source is part of a SourceForge project which always has the
+latest sources in CVS, as well as all of the previous releases.
+
+	https://sourceforge.net/projects/brian-d-foy/
+	
+If, for some reason, I disappear from the world, one of the other
+members of the project can shepherd this module appropriately.
+
 =head1 AUTHOR
 
 brian d foy, E<lt>bdfoy@cpan.orgE<gt>
